==> openGion7.2.6.1_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE70S.sql <==
/****************************************************************************/
/* GE70 ( 取込要求ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2018/09/28 16:03:20                                            */
/****************************************************************************/

CREATE TABLE GE70 (
   SYSTEM_ID        VARCHAR2 (   10 )                   NOT NULL            /*   1 ｼｽﾃﾑID               */
 , RSRV_NO          NUMBER   (    3 )                   NOT NULL            /*   2 予約番号             */
 , NAME_JA          VARCHAR2 (  200 )                                       /*   3 名称                 */
 , EXECID           VARCHAR2 (   20 )                   NOT NULL            /*   4 処理ID               */
 , FGYKAN           VARCHAR2 (    1 )       DEFAULT '2' NOT NULL            /*   5 取込予約ﾌﾗｸﾞ         */
 , DIR_BASE         VARCHAR2 (  200 )                                       /*   6 取込ﾍﾞｰｽﾌｫﾙﾀﾞ        */
 , DIR_SUB          VARCHAR2 (  200 )                                       /*   7 取込ｻﾌﾞﾌｫﾙﾀﾞ         */
 , DIR_WORK         VARCHAR2 (  200 )                                       /*   8 処理ﾌｫﾙﾀﾞ(WORK)      */
 , DIR_BKUP_OK      VARCHAR2 (  200 )                                       /*   9 処理済ﾌｫﾙﾀﾞ(正常)    */
 , DIR_BKUP_NG      VARCHAR2 (  200 )                                       /*  10 処理済ﾌｫﾙﾀﾞ(異常)    */
 , FILE_FILTER      VARCHAR2 ( 4000 )                                       /*  11 検索条件             */
 , RELEASE_NOTES    VARCHAR2 (  120 )                                       /*  12 ﾘﾘｰｽﾉｰﾄ              */
 , RDC_CODE         VARCHAR2 (   20 )                                       /*  13 設変番号             */
 , UNIQ             NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ               */
 , FGJ              VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ             */
 , DYSET            VARCHAR2 (   14 )                                       /* 820 登録日時             */
 , PGSET            VARCHAR2 (   10 )                                       /* 830 作成PG               */
 , PGPSET           VARCHAR2 (   10 )                                       /* 840 作成親PG             */
 , USRSET           VARCHAR2 (   10 )                                       /* 850 作成者               */
 , DYUPD            VARCHAR2 (   14 )                                       /* 860 更新日時             */
 , PGUPD            VARCHAR2 (   10 )                                       /* 870 更新PG               */
 , PGPUPD           VARCHAR2 (   10 )                                       /* 880 更新親PG             */
 , USRUPD           VARCHAR2 (   10 )                                       /* 890 更新者               */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );


CREATE SEQUENCE GE70S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;


CREATE OR REPLACE TRIGGER GE70T00 
  BEFORE INSERT ON GE70
  FOR EACH ROW 
  BEGIN 
    SELECT GE70S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion7.3.1.3_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE70S.sql <==
/****************************************************************************/
/* GE70 ( 取込要求ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2020/12/16 08:13:51                                            */
/****************************************************************************/

CREATE TABLE GE70 (
   SYSTEM_ID        VARCHAR2 (   10 )                   NOT NULL            /*   1 ｼｽﾃﾑID               */
 , RSRV_NO          NUMBER   (    3 )                   NOT NULL            /*   2 予約番号             */
 , NAME_JA          VARCHAR2 (  200 )                                       /*   3 名称                 */
 , EXECID           VARCHAR2 (   20 )                   NOT NULL            /*   4 処理ID               */
 , FGYKAN           VARCHAR2 (    1 )       DEFAULT '2' NOT NULL            /*   5 取込予約ﾌﾗｸﾞ         */
 , DIR_BASE         VARCHAR2 (  200 )                                       /*   6 取込ﾍﾞｰｽﾌｫﾙﾀﾞ        */
 , DIR_SUB          VARCHAR2 (  200 )                                       /*   7 取込ｻﾌﾞﾌｫﾙﾀﾞ         */
 , DIR_WORK         VARCHAR2 (  200 )                                       /*   8 処理ﾌｫﾙﾀﾞ(WORK)      */
 , DIR_BKUP_OK      VARCHAR2 (  200 )                                       /*   9 処理済ﾌｫﾙﾀﾞ(正常)    */
 , DIR_BKUP_NG      VARCHAR2 (  200 )                                       /*  10 処理済ﾌｫﾙﾀﾞ(異常)    */
 , FILE_FILTER      VARCHAR2 ( 4000 )                                       /*  11 検索条件             */
 , RELEASE_NOTES    VARCHAR2 (  120 )                                       /*  12 ﾘﾘｰｽﾉｰﾄ              */
 , RDC_CODE         VARCHAR2 (   20 )                                       /*  13 設変番号             */
 , UNIQ             NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ               */
 , FGJ              VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ             */
 , DYSET            VARCHAR2 (   14 )                                       /* 820 作成日時             */
 , PGSET            VARCHAR2 (   10 )                                       /* 830 作成PG               */
 , PGPSET           VARCHAR2 (   10 )                                       /* 840 作成親PG             */
 , USRSET           VARCHAR2 (   10 )                                       /* 850 作成者               */
 , DYUPD            VARCHAR2 (   14 )                                       /* 860 更新日時             */
 , PGUPD            VARCHAR2 (   10 )                                       /* 870 更新PG               */
 , PGPUPD           VARCHAR2 (   10 )                                       /* 880 更新親PG             */
 , USRUPD           VARCHAR2 (   10 )                                       /* 890 更新者               */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );


CREATE SEQUENCE GE70S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;


CREATE OR REPLACE TRIGGER GE70T00 
  BEFORE INSERT ON GE70
  FOR EACH ROW 
  BEGIN 
    SELECT GE70S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
